Crate sosorted
Source - SIMD_WIDTH_BITS
- SimdMaskOps
- Trait for SIMD mask operations.
- SortedSimdElement
- Trait for scalar types that can be used with SIMD-accelerated sorted operations.
- deduplicate
- Copies elements from
input to out, removing consecutive duplicates.
Returns the number of elements written to out. - difference
- Computes the set difference (a \ b).
- difference_size
- Calculates the size of the set difference (a \ b) without modifying the input.
- find_first_duplicate
- Returns the index of the first duplicate entry. If there are no duplicates, the length of the
slice is returned.
- intersect
- Computes the multiset intersection of two sorted arrays.
- union
- Computes the set union of two sorted arrays, merging them into a destination buffer.
- union_size
- Calculates the size of the union of two sorted arrays without allocating.